\name{stacd.design}
\alias{stacd.design}
\concept{model fitting}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Create design matrix for STACD model
}
\description{
The STACD model is defined based on data for two unlinked biallelic loci. In order to fit the model, it is necessary to convert the data for the two loci into appropriate terms for the eight corresponding model parameters. This function creates that \emph{N by 8} design matrix from the data.
}
\usage{
stacd.design(x, z)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{
the numeric vector of data at the first locus, coded 0,1,2 for the number of reference alleles
}
  \item{z}{
data for the second locus, as \code{x}
}
}
\value{
An \emph{N x 8} design matrix, with columns corresponding to the parameters of the STACD model (excluding \emph{mu}), where $N$ is the length of the data vectors \code{x} and \code{z}. Specifically, the columns of the output contain the appropriate dummy variables for \emph{alpha_1}, \emph{alpha_2}, \emph{beta_1}, \emph{beta_2}, \emph{gamma_ab}, \emph{gamma^*_aab}, \emph{gamma^*_abb}, and \emph{gamma^*_aabb}, respectively.
}
\references{
Walters, R., Laurin, C., and Lubke, G.H. (in prep). Derivation of a logistic model for two-locus genetic interactions.
}
\author{
Raymond Walters
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{stacd.data}} to generate data for the STACD model
}
\examples{
# Generate random data for 2 loci
x <- rbinom(100,2,.5)
z <- rbinom(100,2,.3)

# Create design matrix
dat.M <- stacd.design(x,z)
dat.M

# fit STACD model using design matrix
u <- .2*x + .2*(x*z)
y <- rbinom(1,1,u)
fit <- glm(y~.,data=cbind(y=y,dat.M),family=binomial("logit"))
summary(fit)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ manip }
